==> inspirems-1.3.tar.gz: inspirems-1.3/inspire/input/search_results.py <==
""" Generic functions for reading in any search results.
"""
import os

import pandas as pd

from inspire.input.mascot import read_mascot_data
from inspire.input.maxquant import read_mq_data
from inspire.input.peaks import read_peaks_data
from inspire.utils import add_fixed_modifications

def generic_read_df(config, save_dfs=True):
    """ Function to read in search results from any search engine.

    Parameters
    ----------
    config : inspire.config.Config
        The Config object for the experiment.

    Returns
    -------
    search_df : pd.DataFrame
        A DataFrame of search results.
    mods_df : pd.DataFrame
        A small DataFrame detailing the PTMs found.
    """
    if os.path.exists(f'{config.output_folder}/formated_df.csv') and config.reuse_input:
        search_df = pd.read_csv(f'{config.output_folder}/formated_df.csv')
        mods_df = pd.read_csv(f'{config.output_folder}/formated_mods.csv')
    else:
        if config.search_engine == 'mascot':
            search_df, mods_df = read_mascot_data(
                config.search_results,
                config.scan_title_format,
                config.source_files,
                config.reduce,
                config.source_filename,
            )
        elif config.search_engine == 'maxquant':
            search_df, mods_df = read_mq_data(config.search_results)
        elif config.search_engine == 'peaks':
            search_df, mods_df = read_peaks_data(config.search_results)
        else:
            raise ValueError(f'Unknown Search Engine: {config.search_engine}')

        if config.fixed_modifications is not None:
            search_df, mods_df = add_fixed_modifications(
                search_df,
                mods_df,
                config.fixed_modifications
            )

        if save_dfs and config.reuse_input:
            search_df.to_csv(f'{config.output_folder}/formated_df.csv', index=False)
            mods_df.to_csv(f'{config.output_folder}/formated_mods.csv', index=False)

    return search_df, mods_df

==> inspirems-1.4.tar.gz: inspirems-1.4/inspire/input/search_results.py <==
""" Generic functions for reading in any search results.
"""
import os

import pandas as pd

from inspire.accession import process_accession_groups
from inspire.input.mascot import read_mascot_data
from inspire.input.maxquant import read_mq_data
from inspire.input.peaks import read_peaks_data
from inspire.utils import add_fixed_modifications

def generic_read_df(config, save_dfs=True, overwrite_reduce=False):
    """ Function to read in search results from any search engine.

    Parameters
    ----------
    config : inspire.config.Config
        The Config object for the experiment.
    save_dfs : bool
        Flag indicating whether the formatted dataframes should be saved to disk.
    overwrite_reduce : bool
        Flag indicating whether to force reduction of Mascot dataframe to best hit
        (for CE calibration pipeline).

    Returns
    -------
    search_df : pd.DataFrame
        A DataFrame of search results.
    mods_df : pd.DataFrame
        A small DataFrame detailing the PTMs found.
    """
    if overwrite_reduce:
        reduce_mascot = True
    else:
        reduce_mascot = config.reduce

    if os.path.exists(f'{config.output_folder}/formated_df.csv') and config.reuse_input:
        search_df = pd.read_csv(f'{config.output_folder}/formated_df.csv')
        mods_df = pd.read_csv(f'{config.output_folder}/formated_mods.csv')
    else:
        if config.search_engine == 'mascot':
            search_df, mods_df = read_mascot_data(
                config.search_results,
                config.scan_title_format,
                config.source_files,
                reduce_mascot,
                config.source_filename,
                with_accession=config.use_accession_stratum,
            )
        elif config.search_engine == 'maxquant':
            search_df, mods_df = read_mq_data(config.search_results)
        elif config.search_engine == 'peaks':
            search_df, mods_df = read_peaks_data(config.search_results)
        else:
            raise ValueError(f'Unknown Search Engine: {config.search_engine}')

        if config.fixed_modifications is not None:
            search_df, mods_df = add_fixed_modifications(
                search_df,
                mods_df,
                config.fixed_modifications
            )

        if config.use_accession_stratum:
            search_df = process_accession_groups(search_df, config)

        if save_dfs and config.reuse_input:
            search_df.to_csv(f'{config.output_folder}/formated_df.csv', index=False)
            mods_df.to_csv(f'{config.output_folder}/formated_mods.csv', index=False)

    return search_df, mods_df
